%%{
%% User input
clear,clc
close all
% Input filenames
inname = {'data\400.unv', 'data\600.unv', 'data\1000.unv'};
% Number of data sets
ndata = length(inname);
B = cell(ndata,1);
iVibD=8; %index Vib - Distance/Weg
iVibV=9; %index Vib - Velocity/Geschwindigkeit
iRef1A=16; %index Ref1 - Acceleration/Beschleunigung
discriminator = 160; %Grenzwert fr die Korrektur der Phasensprung
dBM=350;

%Start parameter fit
a0 = zeros(ndata,3);
a0(1,:)=[6 0.2 5];
a0(2,:)=[7 0.03 5];
a0(3,:)=[27 30 5];

a1 = zeros(ndata,3);
a1(1,:)=[27 30 5];
a1(2,:)=[7 0.03 5];
a1(3,:)=[27 30 5];

a2 = zeros(ndata,17);
a2(1,:)=[1 20 1500 2 3e-3 1.1e9 4 10 2.2 0.5e-3 1 7e6 4.4 2 0.8 1e7 4];
a2(2,:)=[1 20 1500 2 3e-3 1.1e9 4 10 2.2 0.5e-3 1 7e6 4.4 2 0.8 1e7 4];
a2(3,:)=[1 20 1500 2 3e-3 1.1e9 4 10 2.2 0.5e-3 1 7e6 4.4 2 0.8 1e7 4];

a=a0;
aL=a1;
aNeely=a2;

tonotopy=zeros(ndata,2)

%% Load data


for ii = 1:ndata
    % Read data
    inname{ii}
    A = readuff(inname{ii});
    length(A{1,3}.nodeN)
end

% Load scan point location info
load .\Scanpoints_Auswertung\scanloc_1000.mat; %Variable: scanloc

% For each data set
for ii = 1%1:ndata
    % Read data
    inname{ii}
    A = readuff(inname{ii});
    scanpoints=A{1,3}.nodeN;
    length(scanpoints)
    iv = 0;
    for iii = 1:length(scanpoints) %first we check which measurementpoints are located on the membrane
        indscanloc=find(scanloc(:,1)==scanpoints(iii),1,'first');
        if scanloc(indscanloc,3)==0 %fr jeden Messpunkt bestimmen ob der auf dem Membran liegt und welche Position er hat.
            iv=iv+1;
            scanlocBM(iv,1)=iii; %index in the data-file
            scanlocBM(iv,2)=scanloc(indscanloc,1); %node number
            scanlocBM(iv,3)=scanloc(indscanloc,2); %distance of the measurementpoint from the RW
        end
    end
    
    Vib = zeros(length(scanlocBM),8); %Initialize output
    Vib(:,1) = scanlocBM(:,2); %Node Number
    Vib(:,2) = scanlocBM(:,3); %Position
    for v = 1:length(scanlocBM)
        Vib(v,3) = (0.983/1.333)*abs(A{1,iVibD}.r3(scanlocBM(v,1))); %Vib: LDV - Distance/Weg corrected for the optical density difference (nair/nwater(@589 nm)=0.983/1.333)
        Vib(v,4) = angle(A{1,iVibD}.r3(scanlocBM(v,1)))*360/(2*pi); %Vib: LDV - Distance/Weg
        Vib(v,5) = 0; %Reserved for the phase-dependent amplitude
        Vib(v,6) = (0.983/1.333)*abs(A{1,iVibV}.r3(scanlocBM(v,1))); %Vib: LDV - Velocity/Geschwindigkeit corrected for the optical density difference (nair/nwater(@589 nm)=0.983/1.333)
        Vib(v,7) = angle(A{1,iVibV}.r3(scanlocBM(v,1)))*360/(2*pi); %Vib: LDV - Velocity/Geschwindigkeit
        Vib(v,8) = 0; %Reserved for the phase-dependent amplitude
    end
    
    freq(ii) = A{1,iVibD}.modeFreq;
    k = strfind(A{1,iVibD}.d1, ':');
    label_freq{ii} = A{1,iVibD}.d1(k+2:end);
    %label_freq{ii} = [num2str(freq(ii) ' Hz'];
    
    [cd indexd] = max(Vib(:,3)); %maximale Amplitude Weg gesucht
    theta0d = Vib(indexd,4);     % Phase
    [cv indexv] = max(Vib(:,6)); % maximale Amplitude Beschleunigung
    theta0v = Vib(indexv,7);
    
    for vi = 1:length(scanlocBM)
        Vib(vi,5)=Vib(vi,3)*cosd(Vib(vi,4)-theta0d);
        Vib(vi,8)=Vib(vi,6)*cosd(Vib(vi,7)-theta0v);
    end
    
    Vib = sortrows(Vib,2); %sorts the rows of Vib in ascending order of the second column (distance from the RW)
    
    %'Compensating' for the 'phasejump':
    phasejump = 0;
    for vi = 1:length(scanlocBM)
        Vib(vi,4)=Vib(vi,4)+phasejump;
        if vi<length(scanlocBM)
            %if Vib(vi,4)<(-70+phasejump) && Vib(vi+1,4)>(70+phasejump)
            if Vib(vi+1,4)>(Vib(vi,4)-phasejump+discriminator) %discriminator for the phasejump is set at 100 degrees.
                phasejump=phasejump-360;
            end
        end
    end
    
    
    %'Compensating' for the 'phasejump':
    phasejump = 0;
    for vi = 1:length(scanlocBM)
        Vib(vi,7)=Vib(vi,7)+phasejump;
        if vi<length(scanlocBM)
            %if Vib(vi,4)<(-70+phasejump) && Vib(vi+1,4)>(70+phasejump)
            if Vib(vi+1,7)>(Vib(vi,7)-phasejump+discriminator) %discriminator for the phasejump is set at 100 degrees.
                phasejump=phasejump-360;
            end
        end
    end
    %%{
  % Grouping (maximum 3) and take the median of those points. The discriminator is the distance between the points (here: < 0.2 mm)    
    iii=1;
    j=1
    while iii <= length(Vib)
      p = 1;
      if ((iii+1)<=length(Vib))
          if (abs(Vib(iii,2)-Vib(iii+1,2))<0.0002)
              p=p+1;
          end
      end
      if ((iii+2)<=length(Vib))
          if (abs(Vib(iii,2)-Vib(iii+1,2))<0.0002)&&(abs(Vib(iii+1,2)-Vib(iii+2,2))<0.0002)
              p=p+1;
          end
      end
      medarray(j,1)=0;
      medarray(j,2)=median (Vib(iii:iii+p-1,2));
      medarray(j,3)=median (Vib(iii:iii+p-1,3));
      medarray(j,4)=median (Vib(iii:iii+p-1,4));
      medarray(j,5)=median (Vib(iii:iii+p-1,5));
      medarray(j,6)=median (Vib(iii:iii+p-1,6));
      medarray(j,7)=median (Vib(iii:iii+p-1,7));
      medarray(j,8)=median (Vib(iii:iii+p-1,8));
      j=j+1;
      iii=iii+p;
    end
   %%}
    
    % fit parameters, function and fitting procedure
    xdata = 1e3*medarray(:,2)';
    ydata = 1e9*medarray(:,3)';
%{
    if ii==8
        clearvars xdata ydata
        xdata = 1e3*medarray(1:30,2)';
        ydata = 1e9*medarray(1:30,3)';
    end
    if ii==4
        clearvars xdata ydata
        xdata = 1e3*medarray(26:end,2)';
        ydata = 1e9*medarray(26:end,3)';
    end
%}    

    fun = @(a,x) a(2).*exp(-(x-a(1)).^2/(2*a(3).^2)); %Gaussian-Function (not normalized!)
    %fun = @(a,x) (a(2)*(x-a(1))+a(3)*(x-a(1)).^2+a(4)*(x-a(1)).^3+a(5)*(x-a(1)).^4+a(6)*(x-a(1)).^5+a(7)*(x-a(1)).^6); %6th order polynome
    a(ii,:) = lsqcurvefit(fun,a0(ii,:),xdata,ydata);
    tonotopy(ii,1)=a(ii,1);
    tonotopy(ii,2)=freq(ii);
    
    
    funL = @(a,x) (2*a(2)./pi)*(a(3)./(4*(x-a(1)).^2+a(3).^2)) %Lorentz function
    %aL(ii,:) = lsqcurvefit(funL,a1(ii,:),xdata,ydata);
    aL(ii,:) = lsqcurvefit(funL,a1(ii,:),xdata,ydata); 
    
    g=1
    funNeely = @(a,x) real(a(1)/(i*2*pi*freq(ii)*g*(((a(2)+a(3)*exp(-a(4)*x))+i*(2*pi*freq(ii)*a(5)-a(6)*exp(-a(7)*x)/(2*pi*freq(ii)))) + (a(8)*exp(-a(9)*x)+i*(2*pi*freq(ii)*a(10)*exp(a(11)*x)-a(12)*exp(-a(13)*x)/(2*pi*freq(ii))))*(a(14)*exp(-a(15)*x)-i*(a(16)*exp(-a(17)*x))/(2*pi*freq(ii)))/((a(8)*exp(-a(9)*x)+i*(2*pi*freq(ii)*a(10)*exp(a(11)*x)-a(12)*exp(-a(13)*x)/(2*pi*freq(ii))))+(a(14)*exp(-a(15)*x)-i*(a(16)*exp(-a(17)*x))/(2*pi*freq(ii)))))));
    %funNeely = @(a,x) a(a(1)/(i*2*pi*400*1*(((a(2)+a(3)*exp(-a(4)*x))+i*(2*pi*400*a(5)-a(6)*exp(-a(7)*x)/(2*pi*400))) + (a(8)*exp(-a(9)*x)+i*(2*pi*400*a(10)*exp(a(11)*x)-a(12)*exp(-a(13)*x)/(2*pi*400)))*(a(14)*exp(-a(15)*x)-i*(a(16)*exp(-a(17)*x))/(2*pi*400))/((a(8)*exp(-a(9)*x)+i*(2*pi*400*a(10)*exp(a(11)*x)-a(12)*exp(-a(13)*x)/(2*pi*400)))+(a(14)*exp(-a(15)*x)-i*(a(16)*exp(-a(17)*x))/(2*pi*400))))));
    fplot(@(x) funNeely(a2(ii,:),x),[0 30])

%    aNeely(ii,:) = lsqcurvefit(funNeely, a2(ii,:), xdata, ydata);
    
    
    xdata = 1e3*medarray(:,2)';
    ydata = 1e9*medarray(:,3)';        
    times = linspace(xdata(1),xdata(end),100);
    plot(times,funNeely(a2(ii,:),times))
    

    
    %%{
    %--- Deutsch Envelop map with phase for overview ---%
    %OpenFig([19 6.1],'latex');
    OpenFig([28 9],'latex');
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6,0.6,0.6];
    for i=1:2
        ax = subplot(1,2,i);
        grey=[0.6,0.6,0.6];
        greylabel=[1,1,1];
        
        if i==1
            [ax,hLine1,hLine2] = plotyy(1e3*medarray(:,2),1e9*medarray(:,3),1e3*medarray(:,2),medarray(:,4)/180);
            set(ax,'NextPlot','add')
            h1(1)=plot(ax(1),1e3*medarray(:,2),1e9*medarray(:,3),'k')
            list1{1}='Amplitude';
            h1(3)=plot(ax(1),times,fun(a(ii,:),times),'Color', [0 0.5 0])
            list1{3}='Fit';
            h1(4)=plot(ax(1),times,funL(aL(ii,:),times),'Color', [0 0.5 1])
            list1{4}='FitLorenz';
%            h1(5)=plot(ax(1),times,funNeely(a2(ii,:),times),'Color', [1 0.5 0])
%            list1{5}='FitNeely';
            h1(2)=plot(ax(2),1e3*medarray(:,2),medarray(:,4)/180,'or')
            list1{2}='Phase';
            xlim(ax(1),[0 140])
            xlim(ax(2),[0 140])
            %ylim(ax(1),[0 30])
            %ylim(ax(2),[-6 6])
            set(ax(2),'xticklab',[],'xtick',[])
            set(hLine1,'color','k')
            set(hLine2,'color','r') 
            set(ax(1),'YColor','k');
            set(ax(2),'YColor','r'); 
            NumTicksX = 8;
            LX1 = get(ax(1),'XLim');
            LX2 = get(ax(2),'XLim');
            set(ax(1),'XTick',linspace(LX1(1),LX1(2),NumTicksX));
            set(ax(2),'XTick',linspace(LX2(1),LX2(2),NumTicksX));
            %NumTicksY = 7;
            LY1 = get(ax(1),'YLim');
            %LY2 = get(ax(2),'YLim');
            %set(ax(1),'YTick',linspace(LY1(1),LY1(2),NumTicksY));
            %set(ax(2),'YTick',linspace(LY2(1),LY2(2),NumTicksY));
            n=get(gca,'xtick');
            set(gca,'xticklabel',sprintf('%0.0f|', n));
            %line([3 3], [LY1(1) LY1(2)], 'Color',grey);
            %line([34.9 34.9], [LY1(1) LY1(2)], 'Color',grey);
            py_text=(LY1(2)-LY1(1))*0.90+LY1(1);            
        else
            hold all
            c={[0 0 1] [0 1 0] [1 0 1] [1 0.5 0]};
            %c = colormap(hot(10));
            %h=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+0),'b',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+60),'g',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+120),'m',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+180),'k');
            h2(1)=plot(1e3*medarray(:,2),1e9*medarray(:,3).*cosd(medarray(:,4)+0), 'Color', c{1});
            list2{1} = '0$^\circ$';
            h2(2)=plot(1e3*medarray(:,2),1e9*medarray(:,3).*cosd(medarray(:,4)+60),'Color', c{2});
            list2{2} = '60$^\circ$';
            h2(3)=plot(1e3*medarray(:,2),1e9*medarray(:,3).*cosd(medarray(:,4)+120),'Color', c{3});
            list2{3} = '120$^\circ$';
            h2(4)=plot(1e3*medarray(:,2),1e9*medarray(:,3).*cosd(medarray(:,4)+180),'Color', c{4});
            list2{4} = '180$^\circ$';
            xlim([0 140])
            ylim([-LY1(2) LY1(2)])
            %line([3 3], [-LY1(2) LY1(2)], 'Color',grey);
            %line([34.9 34.9], [-LY1(2) LY1(2)], 'Color',grey);
            NumTicksX = 8;
            LX = get(gca,'XLim');
            set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
            %NumTicksY = 7;
            LY = get(gca,'YLim')
            %set(gca,'YTick',linspace(LY(1),LY(2),NumTicksY));
            n=get(gca,'xtick');
            set(gca,'xticklabel',sprintf('%0.0f|', n));
            py_text=(LY(2)-LY(1))*0.90+LY(1);
            %
            xlimtxt=get(gca,'XLim');
            xlimtxt=get(gca,'XLim');
            ylimtxt=get(gca,'YLim');
            if freq(ii) >= 1000
                text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
            else
                text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
            end
            %text(xlimtxt(2)+2,py_text,[num2str(mean(A{1,iRef1A}.r3),'%.2f') ' $\mathrm{m/s^2}$ (' num2str(1e9*mean(A{1,iRef1A}.r3)/(2*pi*freq(ii))^2,'%.0f') ' $\mathrm{nm}$)'],'VerticalAlignment','bottom','HorizontalAlignment','left','FontSize',8) 
        end
        grid on
        box on
        %text(30,py_text,[label_freq{ii}],'FontSize',10,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
        %p_width=6;
        p_width=9;
        %p_height=4.5;
        p_height=7.5;
        p_left=3.5;
        %p_right=10;
        p_right=15.5;
        p_bottom=1.4;
        p={[p_left p_bottom p_width p_height] [p_right p_bottom p_width p_height]};
        set(gca, 'position', p{i});
        if i==1
            xlabel(ax(1),'Distanz vom RW in ${\mathrm{mm}}$','FontSize',10)
            ylabel(ax(1),'Amplitude in $\mathrm{nm}$','FontSize',10)
            ylabel(ax(2),'Phase in $\mathrm{\Pi}$','FontSize',16)
            %legend({'Amplitude' 'Fit' 'Phase'},'Position',[24 6 2.0 0.5])
            legend(h1,list1,'Position',[24 6 2.0 0.5])
            legend('boxoff')
        else
            xlabel('Distanz vom RW in ${\mathrm{mm}}$','FontSize',10)
            ylabel('Auslenkung in $\mathrm{nm}$','FontSize',10)
            %legend(h,{'0\circ' '60\circ' '120\circ' '180\circ'},'Position',[26 4 1.0 2],'FontSize',8)
            legend(h2,list2,'Position',[24 2.5 1.0 2])
            legend('boxoff')
        end
    FormatFigXtitle_paper(-1.5,-2,0.4,-0.2);        
    end
    PlotFig(['BM Schwingung und Phase bei ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']); 
    %%}
    
    %{
    %--- Englisch Envelop map with phase for overview ---%
    %OpenFig([19 6.1],'latex');
    OpenFig([28 9],'latex');
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6,0.6,0.6];
    for i=1:2
        ax = subplot(1,2,i);
        grey=[0.6,0.6,0.6];
        greylabel=[1,1,1];
        
        if i==1
            [ax,hLine1,hLine2] = plotyy(1e3*Vib(:,2),1e9*Vib(:,3),1e3*Vib(:,2),Vib(:,4)/180);
            set(ax,'NextPlot','add')
            h1(1)=plot(ax(1),1e3*Vib(:,2),1e9*Vib(:,3),'k')
            list1{1}='Amplitude';
            h1(3)=plot(ax(1),times,fun(a(ii,:),times),'Color', [0 0.5 0])
            list1{3}='Fit';
            h1(2)=plot(ax(2),1e3*Vib(:,2),Vib(:,4)/180,'r')
            list1{2}='Phase';
            xlim(ax(1),[0 35])
            xlim(ax(2),[0 35])
            %ylim(ax(1),[0 30])
            %ylim(ax(2),[-6 6])
            set(ax(2),'xticklab',[],'xtick',[])
            set(hLine1,'color','k')
            set(hLine2,'color','r') 
            set(ax(1),'YColor','k');
            set(ax(2),'YColor','r'); 
            NumTicksX = 8;
            LX1 = get(ax(1),'XLim');
            LX2 = get(ax(2),'XLim');
            set(ax(1),'XTick',linspace(LX1(1),LX1(2),NumTicksX));
            set(ax(2),'XTick',linspace(LX2(1),LX2(2),NumTicksX));
            %NumTicksY = 7;
            LY1 = get(ax(1),'YLim');
            %LY2 = get(ax(2),'YLim');
            %set(ax(1),'YTick',linspace(LY1(1),LY1(2),NumTicksY));
            %set(ax(2),'YTick',linspace(LY2(1),LY2(2),NumTicksY));
            n=get(gca,'xtick');
            set(gca,'xticklabel',sprintf('%0.0f|', n));
            %line([3 3], [LY1(1) LY1(2)], 'Color',grey);
            %line([34.9 34.9], [LY1(1) LY1(2)], 'Color',grey);
            py_text=(LY1(2)-LY1(1))*0.90+LY1(1);            
        else
            hold all
            c={[0 0 1] [0 1 0] [1 0 1] [1 0.5 0]};
            %c = colormap(hot(10));
            %h=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+0),'b',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+60),'g',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+120),'m',1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+180),'k');
            h2(1)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+0), 'Color', c{1});
            list2{1} = '0$^\circ$';
            h2(2)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+60),'Color', c{2});
            list2{2} = '60$^\circ$';
            h2(3)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+120),'Color', c{3});
            list2{3} = '120$^\circ$';
            h2(4)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+180),'Color', c{4});
            list2{4} = '180$^\circ$';
            xlim([0 35])
            ylim([-LY1(2) LY1(2)])
            %line([3 3], [-LY1(2) LY1(2)], 'Color',grey);
            %line([34.9 34.9], [-LY1(2) LY1(2)], 'Color',grey);
            NumTicksX = 8;
            LX = get(gca,'XLim');
            set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
            %NumTicksY = 7;
            LY = get(gca,'YLim')
            %set(gca,'YTick',linspace(LY(1),LY(2),NumTicksY));
            n=get(gca,'xtick');
            set(gca,'xticklabel',sprintf('%0.0f|', n));
            py_text=(LY(2)-LY(1))*0.90+LY(1);
            %
            xlimtxt=get(gca,'XLim');
            xlimtxt=get(gca,'XLim');
            ylimtxt=get(gca,'YLim');
            if freq(ii) >= 1000
                text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
            else
                text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
            end
            %text(xlimtxt(2)+2,py_text,[num2str(mean(A{1,iRef1A}.r3),'%.2f') ' $\mathrm{m/s^2}$ (' num2str(1e9*mean(A{1,iRef1A}.r3)/(2*pi*freq(ii))^2,'%.0f') ' $\mathrm{nm}$)'],'VerticalAlignment','bottom','HorizontalAlignment','left','FontSize',8) 
        end
        grid on
        box on
        %text(30,py_text,[label_freq{ii}],'FontSize',10,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
        %p_width=6;
        p_width=9;
        %p_height=4.5;
        p_height=7.5;
        p_left=3.5;
        %p_right=10;
        p_right=15.5;
        p_bottom=1.4;
        p={[p_left p_bottom p_width p_height] [p_right p_bottom p_width p_height]};
        set(gca, 'position', p{i});
        if i==1
            xlabel(ax(1),'Distance from the RW in ${\mathrm{mm}}$','FontSize',10)
            ylabel(ax(1),'Amplitude in $\mathrm{nm}$','FontSize',10)
            ylabel(ax(2),'Phase in $\mathrm{\Pi}$','FontSize',16)
            %legend({'Amplitude' 'Fit' 'Phase'},'Position',[24 6 2.0 0.5])
            legend(h1,list1,'Position',[24 6 2.0 0.5])
            legend('boxoff')
        else
            xlabel('Distance from the RW in ${\mathrm{mm}}$','FontSize',10)
            ylabel('Deflection in $\mathrm{nm}$','FontSize',10)
            %legend(h,{'0\circ' '60\circ' '120\circ' '180\circ'},'Position',[26 4 1.0 2],'FontSize',8)
            legend(h2,list2,'Position',[24 2.5 1.0 2])
            legend('boxoff')
        end
    FormatFigXtitle_paper(-1.5,-2,0.4,-0.2);        
    end
    PlotFig(['BM Schwingung und Phase at ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']); 
    %}
    
    %{
    %---Deutsch Create a traveling wave graph%
    OpenFig([14 9],'latex');                                                    
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6 0.6 0.6];
    greylabel=[1 1 1];
    c={[0 0 1] [0 1 0] [1 0 1] [1 0.5 0]};
    m = {'o' '^' 's' 'v'}
    h(1)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+0),'Color',c{1});
    list{1} = '0$^\circ$';
    h(2)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+60),'Color',c{2});
    list{2} = '60$^\circ$';
    h(3)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+120),'Color',c{3});
    list{3} = '120$^\circ$';
    h(4)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+180),'Color',c{4});
    list{4} = '180$^\circ$';
    xlim([0 35])
    LY = get(gca,'YLim');
    LY = max(abs(LY))
    ylim([-LY LY])
    NumTicksX = 8;
    LX = get(gca,'XLim');
    set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
    LY = get(gca,'YLim');
    xlimtxt=get(gca,'XLim');
    ylimtxt=get(gca,'YLim');
    if freq(ii) >= 1000
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    else
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    end
    legend(list,'Position',[12 3.8 1.0 2])
    legend('boxoff')
    grid on
    box on
    xlabel('Distanz vom RW in mm')
    ylabel('Auslenkung in nm')
    FormatFigXtitle_paper(-1.5,-2,0.4,-0.2);
    PlotFig(['BM Oscillations bei ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']);
    clearvars list
    %}
    
    %{
    %---Englisch Create a traveling wave graph%
    OpenFig([14 9],'latex');                                                    
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6 0.6 0.6];
    greylabel=[1 1 1];
    c={[0 0 1] [0 1 0] [1 0 1] [1 0.5 0]};
    m = {'o' '^' 's' 'v'}
    h(1)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+0),'Color',c{1});
    list{1} = '0$^\circ$';
    h(2)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+60),'Color',c{2});
    list{2} = '60$^\circ$';
    h(3)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+120),'Color',c{3});
    list{3} = '120$^\circ$';
    h(4)=plot(1e3*Vib(:,2),1e9*Vib(:,3).*cosd(Vib(:,4)+180),'Color',c{4});
    list{4} = '180$^\circ$';
    xlim([0 35])
    LY = get(gca,'YLim');
    LY = max(abs(LY))
    ylim([-LY LY])
    NumTicksX = 8;
    LX = get(gca,'XLim');
    set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
    LY = get(gca,'YLim');
    xlimtxt=get(gca,'XLim');
    ylimtxt=get(gca,'YLim');
    if freq(ii) >= 1000
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    else
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    end
    legend(list,'Position',[12 3.8 1.0 2])
    legend('boxoff')
    grid on
    box on
    xlabel('Distance from the RW in mm')
    ylabel('Deflection in nm')
    FormatFigXtitle_paper(-1.5,-2,0.4,-0.2);
    PlotFig(['BM Oscillations at ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']);
    clearvars list
    %}
    
    %{
    %--- Deutsch Create a traveling wave graph%
    OpenFig([15.9 9],'latex');                                                    
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6 0.6 0.6];
    greylabel=[1 1 1];
    [ax,hLine1,hLine2] = plotyy(1e3*Vib(:,2),1e9*Vib(:,3),1e3*Vib(:,2),Vib(:,4)/180);
    xlim(ax(1),[0 35])
    xlim(ax(2),[0 35])
    set(ax(2),'xticklab',[],'xtick',[])
    set(hLine1,'color','k')
    set(hLine2,'color','r') 
    set(ax(1),'YColor','k');
    set(ax(2),'YColor','r','FontSize',12); 
    NumTicksX = 8;
    LX1 = get(ax(1),'XLim');
    LX2 = get(ax(2),'XLim');
    set(ax(1),'XTick',linspace(LX1(1),LX1(2),NumTicksX));
    set(ax(2),'XTick',linspace(LX2(1),LX2(2),NumTicksX));
    LY1 = get(ax(1),'YLim');
    ylim(ax(1),[0 LY1(2)])
    %ylim(ax(2),[-6 6])
    n=get(gca,'xtick');
    set(gca,'xticklabel',sprintf('%0.0f|', n));
    xlabel(ax(1),'Distance vom RW in mm')
    ylabel(ax(1),'Amplitude in nm')
    ylabel(ax(2),'Phase in $\mathrm{\Pi}$','FontSize',16)
    xlimtxt=get(ax(1),'XLim');
    ylimtxt=get(ax(1),'YLim');
    if freq(ii) >= 1000
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    else
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    end
    legend({'Amplitude' 'Phase'},'Position',[13.5 3.8 1.0 2])
    legend('boxoff')
    grid on
    box on
    FormatFigXtitle_paper(-0.5,-3.7,0.4,-0.2);
    PlotFig(['BM Amplitude and Phase bei ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']);
    clearvars list
    %}
    
    %{
    %--- Englisch Create a traveling wave graph%
    OpenFig([15.9 9],'latex');                                                    
    hold all
    set(gcf,'DefaultLineLineWidth',1.0);
    set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
    grey=[0.6 0.6 0.6];
    greylabel=[1 1 1];
    [ax,hLine1,hLine2] = plotyy(1e3*Vib(:,2),1e9*Vib(:,3),1e3*Vib(:,2),Vib(:,4)/180);
    xlim(ax(1),[0 35])
    xlim(ax(2),[0 35])
    set(ax(2),'xticklab',[],'xtick',[])
    set(hLine1,'color','k')
    set(hLine2,'color','r') 
    set(ax(1),'YColor','k');
    set(ax(2),'YColor','r','FontSize',12); 
    NumTicksX = 8;
    LX1 = get(ax(1),'XLim');
    LX2 = get(ax(2),'XLim');
    set(ax(1),'XTick',linspace(LX1(1),LX1(2),NumTicksX));
    set(ax(2),'XTick',linspace(LX2(1),LX2(2),NumTicksX));
    LY1 = get(ax(1),'YLim');
    ylim(ax(1),[0 LY1(2)])
    %ylim(ax(2),[-6 6])
    n=get(gca,'xtick');
    set(gca,'xticklabel',sprintf('%0.0f|', n));
    xlabel(ax(1),'Distance from the RW in mm')
    ylabel(ax(1),'Amplitude in nm')
    ylabel(ax(2),'Phase in $\mathrm{\Pi}$','FontSize',16)
    xlimtxt=get(ax(1),'XLim');
    ylimtxt=get(ax(1),'YLim');
    if freq(ii) >= 1000
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(floor(freq(ii)/1000)) ' ' label_freq{ii}(length(num2str(floor(freq(ii)/1000)))+1:end-2) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    else
        text(xlimtxt(2)+1,ylimtxt(2),{['$f = $ ' num2str(freq(ii)) ' Hz'];['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']}, 'VerticalAlignment','top', 'FontSize',12,'BackgroundColor',greylabel,'FontWeight','bold','EdgeColor',greylabel,'LineWidth',0.5)
    end
    legend({'Amplitude' 'Phase'},'Position',[13.5 3.8 1.0 2])
    legend('boxoff')
    grid on
    box on
    FormatFigXtitle_paper(-0.5,-3.7,0.4,-0.2);
    PlotFig(['BM Amplitude and Phase at ' label_freq{ii} ' (' inname{ii}(6:end-4) ')']);
    clearvars list
    %}
    
        
    %{
    C = [Vib(:,2), Vib(:,3), Vib(:,4)];
    filename = ['LDVdata_', label_freq{ii}, '.txt'];
    save(filename, 'C', '-ascii');
    %}

    clearvars scanlocBM %Since this variable is not initialized / cleared after each sequence

    B{ii,1}.ID = label_freq{ii}; %each dataset get its unique flag
    B{ii,1}.data = Vib; %the corresponding data

end

matfilename = ['tonotopy_' num2str(dBM) 'um.mat'];
save(matfilename, 'tonotopy');

C = [tonotopy(:,1), tonotopy(:,2)];
filename = ['tonotopy_' num2str(dBM) 'um.txt'];
save(filename, 'C', '-ascii');


%%}


%{
%% Englisch Tonotopic Plot 
%%Load data

%load tonotopy_20um.mat;
%load TPD0k40mmSylgard184.mat;
%load TPD0k27mmSylgard184_beta1Em4.mat;
%load TPD0k27mmSylgard184Jan_beta1Em4.mat;
%load TPD0k27mmSylgard184_beta1Em4_df1k1.mat;

t50 = importdata('tonotopy_20um.txt')
dBM = 50

% Deutsch Tonotopic map 1
OpenFig([21 9],'latex');
hold all
set(gcf,'DefaultLineLineWidth',0.5);
c={[0.5 .5 .5] [0 1 0] [1 0 1] [1 0.5 0]};
grey = [0.5 0.5 0.5]
xlim([0 35])
ylim([10 100000])
% Tonotopic-Data: FastScan-Shaker-Measurements, Simulation at 0.20mm,
% Simulation at 0.40mm
%Greenwood function with the following mammals parameters
A=165.4;
a=2.1;
K=0.88;
L=35;
fun = @(x) A*(10.^(a*(L-x)/L)-K); %Greenwood function
LX = get(gca,'XLim')
times = linspace(LX(1),LX(2),100);

h(1)= plot(times,fun(times),'Color',c{1},'LineWidth',2,'LineStyle','--')
list{1} = 'Greenwood function';
h(2)= plot(t50(2:11,1), t50(2:11,2),'Color',c{2},'LineWidth',1)
list{2} = '$d_{BM} = 50 {\mathrm{\mu m}}$';
%h(3)= plot(t20(:,1),1.5*t20(:,2),'Color',c{3},'LineWidth',1)
%list{3} = '$d_{BM} = 30 {\mathrm{\mu m}}$';
%plot([98.1-10.6,76.9-10.6,67.3-10.6,59.2-10.6,48.0-10.6,35.0-10.6],[100,200,250,300,400,500],'-o')
%plot([98.1,76.9,67.3,59.2,48.0,35.0],[100,200,250,300,400,500],'-o',10.6+1e3*TPD0k20mmSylgard184(:,2),TPD0k20mmSylgard184(:,1),10.6+1e3*TPD0k40mmSylgard184(:,2),TPD0k40mmSylgard184(:,1))
%legend({'FastScan(Shaker)','0.20mm SG184','0.40mm SG184'},'Location','northeast')

set(gca,'yscale','log')
NumTicksX = 8;
LX = get(gca,'XLim');
set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
n=get(gca,'xtick');
set(gca,'xticklabel',sprintf('%0.0f|', n));
n=get(gca,'ytick');
set(gca,'yticklabel',sprintf('%0.0f|', n));
grid on
%set(gca,'ygrid','on')
set(gca,'YMinorGrid','off');
%set(gca,'GridLineStyle','-');
%set(gca,'MinorGridLineStyle',':');
%set(gca, 'XMinorGrid','on', 'YMinorGrid','on', 'XColor','r', 'YColor','g')
box on
xlabel('Distance from the RW in mm')
%xlabel('length $l\textsc{\char13}~[\mathrm{mm}]$')
ylabel('Frequency in Hz') 
%legend({'Greenwood Funktion',['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']},'Location','eastoutside')
legend(h,list,'Location','eastoutside')
legend('boxoff')
FormatFig(1,0.2);
FormatFigXtitle_paper(-1.5,-2,0.4,-0.2)
PlotFig('Tonotopic_map_Englisch');
%%}
%%{
%%Deutsch Tonotopic Plot 
%%Load data

%load tonotopy_20um.mat;
%load TPD0k40mmSylgard184.mat;
%load TPD0k27mmSylgard184_beta1Em4.mat;
%load TPD0k27mmSylgard184Jan_beta1Em4.mat;
%load TPD0k27mmSylgard184_beta1Em4_df1k1.mat;

t20 = importdata('tonotopy_20um.txt')
dBM = 20

% Tonotopic map 1
OpenFig([21 9],'latex');
hold all
set(gcf,'DefaultLineLineWidth',0.5);
c={[0.5 .5 .5] [0 1 0] [1 0 1] [1 0.5 0]};
grey = [0.5 0.5 0.5]
xlim([0 35])
ylim([10 100000])
% Tonotopic-Data: FastScan-Shaker-Measurements, Simulation at 0.20mm,
% Simulation at 0.40mm
%Greenwood function with the following mammals parameters
A=165.4;
a=2.1;
K=0.88;
L=35;
fun = @(x) A*(10.^(a*(L-x)/L)-K); %Greenwood function
LX = get(gca,'XLim')
times = linspace(LX(1),LX(2),100);

h(1)= plot(times,fun(times),'Color',c{1},'LineWidth',2,'LineStyle','--')
list{1} = 'Greenwood Funktion';
h(2)= plot(t20(2:11,1), t20(2:11,2),'Color',c{2},'LineWidth',1)
list{2} = '$d_{BM} = 20 {\mathrm{\mu m}}$';
%h(3)= plot(t20(:,1),1.5*t20(:,2),'Color',c{3},'LineWidth',1)
%list{3} = '$d_{BM} = 30 {\mathrm{\mu m}}$';
%plot([98.1-10.6,76.9-10.6,67.3-10.6,59.2-10.6,48.0-10.6,35.0-10.6],[100,200,250,300,400,500],'-o')
%plot([98.1,76.9,67.3,59.2,48.0,35.0],[100,200,250,300,400,500],'-o',10.6+1e3*TPD0k20mmSylgard184(:,2),TPD0k20mmSylgard184(:,1),10.6+1e3*TPD0k40mmSylgard184(:,2),TPD0k40mmSylgard184(:,1))
%legend({'FastScan(Shaker)','0.20mm SG184','0.40mm SG184'},'Location','northeast')

set(gca,'yscale','log')
NumTicksX = 8;
LX = get(gca,'XLim');
set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
n=get(gca,'xtick');
set(gca,'xticklabel',sprintf('%0.0f|', n));
n=get(gca,'ytick');
set(gca,'yticklabel',sprintf('%0.0f|', n));
grid on
%set(gca,'ygrid','on')
set(gca,'YMinorGrid','off');
%set(gca,'GridLineStyle','-');
%set(gca,'MinorGridLineStyle',':');
%set(gca, 'XMinorGrid','on', 'YMinorGrid','on', 'XColor','r', 'YColor','g')
box on
xlabel('Distanz vom RW in mm')
%xlabel('length $l\textsc{\char13}~[\mathrm{mm}]$')
ylabel('Frequenz in Hz') 
%legend({'Greenwood Funktion',['$d_{BM} =$ ' num2str(dBM) ' ${\mathrm{\mu m}}$']},'Location','eastoutside')
legend(h,list,'Location','eastoutside')
legend('boxoff')
FormatFig(1,0.2);
FormatFigXtitle_paper(-1.5,-2,0.4,-0.2)
PlotFig('Tonotopic_map_Deutsch');
%}


%{
% Envelop map
OpenFig([14 9],'latex');
hold all
set(gcf,'DefaultLineLineWidth',1);
set(gca, 'LineStyleOrder', {'-', '-.', '--', ':'});
grey=[0.6,0.6,0.6];
for vi=1:size(B,1)
    h(vi) = plot(1e3*B{vi,1}.data(:,2),1e9*B{vi,1}.data(:,3));
    list{vi} = B{vi,1}.ID;
end
xlim([0 40])
%ylim([-1 1])
LY = get(gca,'YLim')
line([3 3], [LY(1) LY(2)], 'Color',grey);
line([34.9 34.9], [LY(1) LY(2)], 'Color',grey);
legend(h, list,'Location','northeastoutside')
NumTicksX = 9;
LX = get(gca,'XLim');
set(gca,'XTick',linspace(LX(1),LX(2),NumTicksX));
n=get(gca,'xtick');
set(gca,'xticklabel',sprintf('%0.0f|', n));
grid on
box on
xlabel('Distanz vom RF $({\mathrm{mm}})$')
ylabel('Amplitude $(\mathrm{nm})$')
FormatFig(-0.7,0.2);
PlotFig(['BM Schwingung (all)']);
clearvars list
%}