%function scanpointloc(varargin)
% function scanpointloc(maindir,subdir,dataset,filename,nodenum_base,nodenum_apex)

clear,clc
close all

%% Load data - Input filename
%maindir = varargin{1};
%subdir = varargin{2};
%dataset = varargin{3};
%filename = varargin{4};
maindir = '161101_TestRig_FastScan';
dataset = 'data';
filename = '1000.unv';

%% Defining the upper point located at the membrane (index_apex) and the
% closest point to the RW (located at the BM).
nodenum_base = 63;
nodenum_apex = 46; % Index wird mittels Polytec Viewer ermittelt, die Position dieser Index 
                   % in der Datei ist in 'scanpoints' zu finden. Wichtig ist dieser Wert.



%% Extract the number and location of the scanpoints
datafile = ['..\..\' maindir '\' dataset '\' filename]
A = readuff(datafile);
%[A{1,3}.nodeN A{1,3}.x*1e3 A{1,3}.y*1e3] %brauchst du nicht wirklich aber wenn du kein Zugriff auf den Polytec Viewer hast, kannst du es auch so ermitteln.
scanpoints = A{1,3}.nodeN;
IndXYZ = zeros(length(scanpoints),4);
IndXYZ(:,1) = A{1,3}.nodeN;
IndXYZ(:,2) = A{1,3}.x;
IndXYZ(:,3) = A{1,3}.y;
IndXYZ(:,4) = A{1,3}.z;

% Plot the location of the scanpoints in the xy-plane
OpenFig([10 8],'latex');
hold on
set(gcf,'DefaultLineLineWidth',0.5);
plot(IndXYZ(:,2)*1e3,IndXYZ(:,3)*1e3,'k*')%Umrechnen in mm
grid on
box on
xlabel('Abstand in x-Richtung in mm')
ylabel('Abstand in y-Richtung in mm')
legend('XYZ LDV','Location','East')
FormatFig(-1.5,0.2);
PlotFig(['scanpoints_' filename(1:end-4) '_original']);


%% Finding the index of a scanpoint
index_base = find(scanpoints==nodenum_base,1)
index_apex = find(scanpoints==nodenum_apex,1)


%% Determination of the rotation angle ("Winkelversatz") (in degrees)
theta=atan((IndXYZ(index_apex,2)-IndXYZ(index_base,2))/(IndXYZ(index_apex,3)-IndXYZ(index_base,3))); % Y = atand(X) returns the inverse tangent (tan-1) of the elements of X in degrees
theta_degrees=theta*180/pi
% Definition of the apex measurementpoint as the coordination origin
% ("Koordinationsursprung") because this measurementpoint is available
% throughout the different measurements
XYZ = zeros(length(scanpoints),3);
XYZ(:,1) = A{1,3}.x-IndXYZ(index_base,2);
XYZ(:,2) = A{1,3}.y-IndXYZ(index_base,3);
XYZ(:,3) = A{1,3}.z-IndXYZ(index_base,4);

% Rotation of the coordinates along the z-axis
XYZrot = zeros(length(scanpoints),3);
% For each scanpoint
for ii = 1:length(scanpoints)
    XYZrot(ii,:)=([cos(theta), -sin(theta), 0; sin(theta), cos(theta), 0; 0, 0, 1]*XYZ(ii,:)')';    
end

%Correction of the xy-coordinates based on the measurements
XYZrot(index_base,2) %Value: -0.03645 (distance between RW and TM)
correctionfactor = 1 %0.0319/XYZrot(index_apex,1) % correction factor for all measurements

IndXYZ(:,2) = correctionfactor * XYZrot(:,1);
IndXYZ(:,3) = correctionfactor * XYZrot(:,2) + 0.1293;

% Plot the transformed scanpoints in the xy-plane
OpenFig([10 8],'latex');
hold on
set(gcf,'DefaultLineLineWidth',0.5);
%%%%%plot(XYZ(:,1),XYZ(:,2),'*',XYZrot(:,1),XYZrot(:,2),'x',IndXYZ(:,2),IndXYZ(:,3),'o');
%plot(XYZ(:,1)*10^3,XYZ(:,2)*10^3,'*',XYZrot(:,1)*10^3,XYZrot(:,2)*10^3,'x',IndXYZ(:,2)*10^3,IndXYZ(:,3)*10^3,'o');% Umrechnen von m in mm
plot(XYZ(:,1)*1e3,XYZ(:,2)*1e3,'x',IndXYZ(:,2)*1e3,IndXYZ(:,3)*1e3,'ro');
grid on
box on
xlabel('x$_{\mathrm{trans}}$ in mm')
ylabel('y$_{\mathrm{trans}}$ in mm')
legend('XYZ','IndXYZ','Location','east')
FormatFig(-0.1,0.2);
PlotFig(['scanpoints_' filename(1:end-4) '_transformed']);

% Scanpoint index and his y-position
scanloc = zeros(length(scanpoints),3);
scanloc(:,1) = IndXYZ(:,1);
scanloc(:,2) = IndXYZ(:,3);

% For each scanpoint. Definition: "0" = points on the BM, "1" = reference
% points located next to the BM-points, "2" = housing / points located at
% top of the test rig.
for ii = 1:length(scanpoints)
    if IndXYZ(ii,2)>-0.0025 && IndXYZ(ii,2)<0.0025 
        scanloc(ii,3)=0;
        elseif IndXYZ(ii,2)>-0.01 && IndXYZ(ii,2)<0.01
            scanloc(ii,3)=1;
            else 
            scanloc(ii,3)=2;
    end
end

%% Save the scanpoint locations locally and in the corresponding directory
matfilename = ['scanloc_' filename(1:end-4) '.mat'];
matfileloc = ['..\..\' maindir '\' matfilename]

save(matfilename, 'scanloc');
save(matfileloc, 'scanloc');


%%


